@@ -4,6 +4,8 @@
 package config
 
 import (
+	"os"
+	"path/filepath"
 	"testing"
 
 	"github.com/stretchr/testify/assert"
@@ -176,3 +178,67 @@ func TestMultiplePluginFilesLoad(t *testing.T) {
 		})
 	}
 }
+
+func TestPluginLoadSymlink(t *testing.T) {
+	tmp := t.TempDir()
+
+	linkFile := filepath.Join(tmp, "plugins-symlink.yaml")
+	wd, err := os.Getwd()
+	require.NoError(t, err)
+	require.NoError(t, os.Symlink(filepath.Join(wd, "testdata", "plugins", "plugins.yaml"), linkFile))
+
+	linkDir := filepath.Join(tmp, "plugins-dir-symlink")
+	require.NoError(t, os.Symlink(filepath.Join(wd, "testdata", "plugins", "dir"), linkDir))
+
+	// Add a symlink with an infinite loop
+	loopDir := filepath.Join(tmp, "loop")
+	require.NoError(t, os.Mkdir(loopDir, 0o755))
+	require.NoError(t, os.Symlink(loopDir, filepath.Join(loopDir, "self")))
+
+	p := NewPlugins()
+	require.NoError(t, p.loadDir(tmp))
+
+	ee := Plugins{
+		Plugins: plugins{
+			"blah": Plugin{
+				Scopes:      []string{"po", "dp"},
+				Args:        []string{"-n", "$NAMESPACE", "-boolean"},
+				ShortCut:    "shift-s",
+				Description: "blee",
+				Command:     "duh",
+				Confirm:     true,
+			},
+			"snippet.1": {
+				ShortCut:        "shift-s",
+				Command:         "duh",
+				Scopes:          []string{"po", "dp"},
+				Args:            []string{"-n", "$NAMESPACE", "-boolean"},
+				Description:     "blee",
+				Confirm:         true,
+				OverwriteOutput: true,
+			},
+			"snippet.2": {
+				Scopes:      []string{"svc", "ing"},
+				Args:        []string{"-n", "$NAMESPACE", "-oyaml"},
+				ShortCut:    "shift-r",
+				Description: "bla",
+				Command:     "duha",
+				Background:  true,
+			},
+			"crapola": {
+				Scopes:      []string{"pods"},
+				Command:     "crapola",
+				Description: "crapola",
+				ShortCut:    "Shift-1",
+			},
+			"bozo": {
+				Scopes:      []string{"pods", "svc"},
+				Command:     "bozo",
+				Description: "bozo",
+				ShortCut:    "Shift-2",
+			},
+		},
+	}
+
+	assert.Equal(t, ee, p)
+}
