@@ -39,7 +39,7 @@ func TestColor(t *testing.T) {
 
 func TestSkinHappy(t *testing.T) {
 	s := config.NewStyles()
-	require.NoError(t, s.Load("../../skins/black-and-wtf.yaml"))
+	require.NoError(t, s.Load("../../skins/black-and-wtf.yaml", false))
 	s.Update()
 
 	assert.Equal(t, "#ffffff", s.Body().FgColor.String())
@@ -72,7 +72,7 @@ Invalid type. Expected: object, given: array`,
 		u := uu[k]
 		t.Run(k, func(t *testing.T) {
 			s := config.NewStyles()
-			err := s.Load(u.f)
+			err := s.Load(u.f, false)
 			if err != nil {
 				assert.Equal(t, u.err, err.Error())
 			}
