@@ -90,10 +90,7 @@ func (c *Container) bindKeys(aa *ui.KeyActions) {
 	aa.Bulk(ui.KeyMap{
 		ui.KeyF:      ui.NewKeyAction("Show PortForward", c.showPFCmd, true),
 		ui.KeyShiftF: ui.NewKeyAction("PortForward", c.portFwdCmd, true),
-		ui.KeyShiftT: ui.NewKeyAction("Sort Restart", c.GetTable().SortColCmd("RESTARTS", false), false),
-		ui.KeyShiftI: ui.NewKeyAction("Sort Idx", c.GetTable().SortColCmd("IDX", true), false),
 	})
-	aa.Merge(resourceSorters(c.GetTable()))
 }
 
 func (c *Container) k9sEnv() Env {
@@ -164,9 +161,21 @@ func (c *Container) shellCmd(evt *tcell.EventKey) *tcell.EventKey {
 		return evt
 	}
 
+	var err error
 	c.Stop()
-	defer c.Start()
-	shellIn(c.App(), c.GetTable().Path, path)
+	defer func() {
+		c.Start()
+		if err != nil {
+			c.App().QueueUpdate(func() {
+				if err != nil {
+					c.App().Flash().Errf("Shell exec failed: %s", err)
+				}
+			})
+
+			c.App().Flash().Err(err)
+		}
+	}()
+	err = shellIn(c.App(), c.GetTable().Path, path)
 
 	return nil
 }
