@@ -15,7 +15,7 @@ import (
 func TestContext(t *testing.T) {
 	ctx := view.NewContext(client.CtGVR)
 
-	require.NoError(t, ctx.Init(makeCtx()))
+	require.NoError(t, ctx.Init(makeCtx(t)))
 	assert.Equal(t, "Contexts", ctx.Name())
-	assert.Len(t, ctx.Hints(), 5)
+	assert.Len(t, ctx.Hints(), 8)
 }
