@@ -130,14 +130,8 @@ func (p *Pod) bindKeys(aa *ui.KeyActions) {
 	}
 
 	aa.Bulk(ui.KeyMap{
-		ui.KeyO:      ui.NewKeyAction("Show Node", p.showNode, true),
-		ui.KeyShiftR: ui.NewKeyAction("Sort Ready", p.GetTable().SortColCmd(readyCol, true), false),
-		ui.KeyShiftT: ui.NewKeyAction("Sort Restart", p.GetTable().SortColCmd("RESTARTS", false), false),
-		ui.KeyShiftS: ui.NewKeyAction("Sort Status", p.GetTable().SortColCmd(statusCol, true), false),
-		ui.KeyShiftI: ui.NewKeyAction("Sort IP", p.GetTable().SortColCmd("IP", true), false),
-		ui.KeyShiftO: ui.NewKeyAction("Sort Node", p.GetTable().SortColCmd("NODE", true), false),
+		ui.KeyO: ui.NewKeyAction("Show Node", p.showNode, true),
 	})
-	aa.Merge(resourceSorters(p.GetTable()))
 }
 
 func (p *Pod) logOptions(prev bool) (*dao.LogOptions, error) {
@@ -393,28 +387,34 @@ func containerShellIn(a *App, comp model.Component, path, co string) error {
 }
 
 func resumeShellIn(a *App, c model.Component, path, co string) {
+	var err error
 	c.Stop()
-	defer c.Start()
+	defer func() {
+		c.Start()
+		a.QueueUpdate(func() {
+			if err != nil {
+				a.Flash().Errf("Shell exec failed: %s", err)
+			}
+		})
+	}()
 
-	shellIn(a, path, co)
+	err = shellIn(a, path, co)
 }
 
-func shellIn(a *App, fqn, co string) {
+func shellIn(a *App, fqn, co string) error {
 	platform, err := getPodOS(a.factory, fqn)
 	if err != nil {
-		slog.Warn("OS detect failed", slogs.Error, err)
+		slog.Warn("OS detection failed (assuming linux)", slogs.Error, err)
+		platform = "linux"
 	}
-	args := computeShellArgs(fqn, co, a.Conn().Config().Flags(), platform)
 
+	args := computeShellArgs(fqn, co, a.Conn().Config().Flags(), platform)
 	c := color.New(color.BgGreen).Add(color.FgBlack).Add(color.Bold)
-	err = runK(a, &shellOpts{
+	return runK(a, &shellOpts{
 		clear:  true,
 		banner: c.Sprintf(bannerFmt, fqn, co),
 		args:   args},
 	)
-	if err != nil {
-		a.Flash().Errf("Shell exec failed: %s", err)
-	}
 }
 
 func containerAttachIn(a *App, comp model.Component, path, co string) error {
@@ -586,14 +586,3 @@ func osFromSelector(s map[string]string) (string, bool) {
 
 	return platform, ok
 }
-
-func resourceSorters(t *Table) *ui.KeyActions {
-	return ui.NewKeyActionsFromMap(ui.KeyMap{
-		ui.KeyShiftC:   ui.NewKeyAction("Sort CPU", t.SortColCmd(cpuCol, false), false),
-		ui.KeyShiftM:   ui.NewKeyAction("Sort MEM", t.SortColCmd(memCol, false), false),
-		ui.KeyShiftX:   ui.NewKeyAction("Sort CPU/R", t.SortColCmd("%CPU/R", false), false),
-		ui.KeyShiftZ:   ui.NewKeyAction("Sort MEM/R", t.SortColCmd("%MEM/R", false), false),
-		tcell.KeyCtrlX: ui.NewKeyAction("Sort CPU/L", t.SortColCmd("%CPU/L", false), false),
-		tcell.KeyCtrlQ: ui.NewKeyAction("Sort MEM/L", t.SortColCmd("%MEM/L", false), false),
-	})
-}
